@@ -1,22 +1,29 @@
 """MQTT Binary sensor entity module."""
+import asyncio
 import json
 import logging
-from typing import Any, Dict, Optional, Union
+from collections.abc import Callable
+from contextlib import AsyncExitStack
+from typing import Any
+
+import asyncio_mqtt as mqtt
 
 from mqtt_hass_base.const import BINARY_SENSOR_DEVICE_CLASSES
 from mqtt_hass_base.entity.common import EntitySettingsType, MqttEntity
 from mqtt_hass_base.error import MQTTHassBaseError
 
 
-class BinarySensorSettingsType(EntitySettingsType, total=False):
+class BinarySensorSettingsType(
+    EntitySettingsType, total=False
+):  # pylint: disable=too-few-public-methods
     """Binary sensor entity settings dict format."""
 
-    device_class: Optional[str]
-    expire_after: Optional[int]
-    force_update: Optional[bool]
-    off_delay: Optional[int]
+    device_class: str | None
+    expire_after: int | None
+    force_update: bool | None
+    off_delay: int | None
     icon: str
-    state_class: Optional[str]
+    state_class: str | None
 
 
 class MqttBinarysensor(MqttEntity):
@@ -31,18 +38,20 @@ class MqttBinarysensor(MqttEntity):
         self,
         name: str,
         unique_id: str,
+        mqtt_client: mqtt.Client,
         mqtt_discovery_root_topic: str,
         mqtt_data_root_topic: str,
         logger: logging.Logger,
-        device_payload: Optional[Dict[str, str]] = None,
-        subscriptions: Optional[Dict[str, str]] = None,
-        device_class: Optional[str] = None,
-        expire_after: Optional[int] = 0,
-        force_update: Optional[bool] = False,
-        off_delay: Optional[int] = None,
+        device_payload: dict[str, str] | None = None,
+        subscriptions: dict[str, Callable[..., Any]] | None = None,
+        device_class: str | None = None,
+        expire_after: int | None = 0,
+        force_update: bool | None = False,
+        off_delay: int | None = None,
         icon: str = "",
-        state_class: Optional[str] = None,
-        object_id: Optional[str] = None,
+        state_class: str | None = None,
+        object_id: str | None = None,
+        entity_category: str | None = None,
     ):
         """Create a new MQTT binary sensor entity object."""
         # MqttEntity.__init__(self, name, mqtt_discovery_root_topic, logger, device_payload)
@@ -50,11 +59,13 @@ class MqttBinarysensor(MqttEntity):
             self,
             name,
             unique_id,
+            mqtt_client,
             mqtt_discovery_root_topic,
             mqtt_data_root_topic,
             logger,
             device_payload,
             object_id=object_id,
+            entity_category=entity_category,
         )
         self._device_class = device_class
         if (
@@ -70,7 +81,7 @@ class MqttBinarysensor(MqttEntity):
         self._state_class = state_class
         self._icon = icon
 
-    def register(self) -> None:
+    async def register(self) -> None:
         """Register the current entity to Hass.
 
         Using the MQTT discovery feature of Home Assistant.
@@ -102,29 +113,36 @@ class MqttBinarysensor(MqttEntity):
         if self._icon:
             config_payload["icon"] = self._icon
         if self._object_id:
-            config_payload["object_id"] = self._object_id
+            config_payload["object_id"] = self.object_id
+        if self.entity_category:
+            config_payload["entity_category"] = self.entity_category
 
         self.logger.debug("%s: %s", self.config_topic, json.dumps(config_payload))
-        self._mqtt_client.publish(
+        await self._mqtt_client.publish(
             topic=self.config_topic, retain=True, payload=json.dumps(config_payload)
         )
 
-    def send_state(
+    async def subscribe(self, stack: AsyncExitStack) -> set[asyncio.Task[None]]:
+        """Subscribe to all mqtt topics needed."""
+        return set()
+
+    async def send_state(
         self,
-        state: Union[str, bytes, float, int],
-        attributes: Optional[Dict[str, Any]] = None,
+        state: str | bytes | float | int,
+        attributes: dict[str, Any] | None = None,
     ) -> None:
         """Send the current state of the sensor to Home Assistant."""
         if isinstance(state, (bytes, str)):
             state = state[:255]
-        self._mqtt_client.publish(topic=self.state_topic, retain=True, payload=state)
-        if attributes is not None:
-            self.send_attributes(attributes)
+        await self._mqtt_client.publish(
+            topic=self.state_topic, retain=True, payload=state
+        )
+        await self.send_attributes(attributes)
 
-    def send_on(self, attributes: Optional[Dict[str, Any]] = None) -> None:
+    async def send_on(self, attributes: dict[str, Any] | None = None) -> None:
         """Send the ON state of the sensor to Home Assistant."""
-        self.send_state("ON", attributes=attributes)
+        await self.send_state("ON", attributes=attributes)
 
-    def send_off(self, attributes: Optional[Dict[str, Any]] = None) -> None:
+    async def send_off(self, attributes: dict[str, Any] | None = None) -> None:
         """Send the OFF state of the sensor to Home Assistant."""
-        self.send_state("OFF", attributes=attributes)
+        await self.send_state("OFF", attributes=attributes)
